@@ -52,55 +52,6 @@ func (p *Policy) VerifyCosignedTreeHead(logKeyHash *crypto.Hash,
 	return nil
 }
 
-type quorumSingle struct {
-	w crypto.Hash
-}
-
-func (q *quorumSingle) IsQuorum(verified map[crypto.Hash]struct{}) bool {
-	_, ok := verified[q.w]
-	return ok
-}
-
-type quorumKofN struct {
-	subQuorums []Quorum
-	k          int
-}
-
-func (q *quorumKofN) IsQuorum(verified map[crypto.Hash]struct{}) bool {
-	c := 0
-	for _, sq := range q.subQuorums {
-		if sq.IsQuorum(verified) {
-			c++
-		}
-	}
-	return c >= q.k
-}
-
-func newEmptyPolicy() *Policy {
-	return &Policy{
-		logs:      make(map[crypto.Hash]Entity),
-		witnesses: make(map[crypto.Hash]Entity),
-	}
-}
-
-func (p *Policy) addLog(log *Entity) (crypto.Hash, error) {
-	h := crypto.HashBytes(log.PublicKey[:])
-	if _, dup := p.logs[h]; dup {
-		return crypto.Hash{}, fmt.Errorf("duplicate log: %x\n", log.PublicKey)
-	}
-	p.logs[h] = *log
-	return h, nil
-}
-
-func (p *Policy) addWitness(witness *Entity) (crypto.Hash, error) {
-	h := crypto.HashBytes(witness.PublicKey[:])
-	if _, dup := p.witnesses[h]; dup {
-		return crypto.Hash{}, fmt.Errorf("duplicate witness: %x\n", witness.PublicKey)
-	}
-	p.witnesses[h] = *witness
-	return h, nil
-}
-
 func randomizeEntities(m map[crypto.Hash]Entity) []Entity {
 	entities := make([]Entity, 0, len(m))
 	for _, entity := range m {
@@ -123,27 +74,40 @@ func (p *Policy) GetWitnessesWithUrl() []Entity {
 	return randomizeEntities(p.witnesses)
 }
 
+func NewPolicy(settings ...Setting) (*Policy, error) {
+	b := newBuilder()
+	for _, s := range settings {
+		if err := s.apply(b); err != nil {
+			return nil, err
+		}
+	}
+	return b.finish()
+}
+
 func NewKofNPolicy(logs, witnesses []crypto.PublicKey, k int) (*Policy, error) {
+	var settings []Setting
+
 	if k > len(witnesses) {
 		return nil, fmt.Errorf("invalid policy k (%d) > n (%d)\n", k, len(witnesses))
 	}
-	p := newEmptyPolicy()
-
 	for _, l := range logs {
-		if _, err := p.addLog(&Entity{PublicKey: l}); err != nil {
-			return nil, err
-		}
+		settings = append(settings, AddLog(&Entity{PublicKey: l}))
 	}
 
-	subQuorums := []Quorum{}
-
-	for _, w := range witnesses {
-		h, err := p.addWitness(&Entity{PublicKey: w})
-		if err != nil {
-			return nil, err
+	if len(witnesses) > 0 {
+		// TODO: Extend the builder interface so that a policy can be
+		// defined without using names to refer between groups and
+		// witnesses?
+		var names []string
+		for i, w := range witnesses {
+			name := fmt.Sprintf("w%d", i)
+			settings = append(settings, AddWitness(name, &Entity{PublicKey: w}))
+			names = append(names, name)
 		}
-		subQuorums = append(subQuorums, &quorumSingle{h})
+		settings = append(settings, AddGroup("g", k, names))
+		settings = append(settings, SetQuorum("g"))
+	} else {
+		settings = append(settings, SetQuorum("none"))
 	}
-	p.quorum = &quorumKofN{subQuorums: subQuorums, k: k}
-	return p, nil
+	return NewPolicy(settings...)
 }
